@@ -58,7 +58,7 @@ int __bfgsmin_obj(double &obj, const std::string f, const octave_value_list f_ar
 int __numgradient(ColumnVector &derivative, const std::string f, const octave_value_list f_args, const int minarg)
 {
   double SQRT_EPS, diff, delta, obj_left, obj_right, p;
-  int j, test, success;
+  int j, test, success = 0;
   ColumnVector parameter = f_args(minarg - 1).column_vector_value();
   int k = parameter.rows();
   ColumnVector g(k);
@@ -273,8 +273,8 @@ Users should not use this directly. Use bfgsmin.m instead")
   octave_value_list f_args, f_return; // holder for return items
 
   int max_iters, verbosity, criterion, minarg, convergence, iter, memory,
-    gradient_ok, i, j, k, conv_fun, conv_param, conv_grad, have_gradient,
-    try_gradient, warnings;
+    gradient_ok, i, j, k, conv_fun = 0, conv_param = 0, conv_grad = 0,
+    have_gradient, try_gradient, warnings;
   double func_tol, param_tol, gradient_tol, stepsize, obj_value, obj_in,
     last_obj_value, denominator, test;
   Matrix H, H1, H2;
@@ -316,7 +316,7 @@ Users should not use this directly. Use bfgsmin.m instead")
   try_gradient = 1;  // try to get analytic gradient
   convergence = -1; // if this doesn't change, it means that maxiters were exceeded
   thetain = theta;
-  H = identity_matrix(k,k);
+  H = OCTAVE__IDENTITY_MATRIX(k,k);
 
   // Initial obj_value
   __bfgsmin_obj(obj_in, f, f_args, theta, minarg);
@@ -349,9 +349,7 @@ Users should not use this directly. Use bfgsmin.m instead")
       else
         d = -H*g; // ordinary bfgs
       // convergence tests
-      conv_fun = 0;
-      conv_param = 0;
-      conv_grad = 0;
+
       // function convergence
       p = theta+d;
       __bfgsmin_obj(obj_value, f, f_args, p, minarg);
@@ -387,7 +385,7 @@ Users should not use this directly. Use bfgsmin.m instead")
           // fall back to steepest descent
           if (warnings) warning("bfgsmin: BFGS direction fails, switch to steepest descent");
           d = -g; // try steepest descent
-          H = identity_matrix(k,k); // accompany with Hessian reset, for good measure
+          H = OCTAVE__IDENTITY_MATRIX(k,k); // accompany with Hessian reset, for good measure
           obj_value = last_obj_value;
           __newtonstep(stepsize, obj_value, f, f_args, theta, d, minarg, warnings);
           if (stepsize == 0.0)
@@ -443,7 +441,7 @@ Users should not use this directly. Use bfgsmin.m instead")
               if ((fabs(denominator) < DBL_EPSILON))
                 {  // reset Hessian if necessary
                   if (verbosity == 1) printf("bfgsmin: Hessian reset\n");
-                  H = identity_matrix(k,k);
+                  H = OCTAVE__IDENTITY_MATRIX(k,k);
                 }
               else
                 {
@@ -455,7 +453,7 @@ Users should not use this directly. Use bfgsmin.m instead")
                 }
             }
           else
-            H = identity_matrix(k,k); // reset hessian if gradient fails
+            H = OCTAVE__IDENTITY_MATRIX(k,k); // reset hessian if gradient fails
           // then try to start again with steepest descent
         }
       else
